# Django settings
SECRET_KEY = "tests"

DATABASES = {
    "default": {
        "ENGINE": "django.db.backends.sqlite3",
        "NAME": ":memory:",
    }
}

INSTALLED_APPS = [
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sites",

    "djtools.seo",
]

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'APP_DIRS': True,
    }
]



class SEOMixin:
    seo_title = None
    seo_description = None

    def get_seo_title(self):
        return self.seo_title

    def get_seo_description(self):
        return self.seo_description

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        context.update({
            'seo_title': self.get_seo_title(),
            'seo_description': self.get_seo_description(),
        })
        return context
